<?php

/**
 * Controller for swfaddress administrative settings.
 */
function swfaddress_admin_form() {
  $form['swfaddress_replacement_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Replacement Enabled'),
    '#description' => t('Turns on the module, enabling Flash replacement according to the settings you enter below.'),
    '#default_value' => variable_get('swfaddress_replacement_enabled', FALSE)
  );

  $form['swfaddress_send_aliases'] = array(
    '#type' => 'checkbox',
    '#title' => t('Send Aliases'),
    '#description' => t('If selected, SWFAddress will send your SWF file aliased paths like <em>about-me</em> rather than Drupal system paths like <em>node/46</em>.'),
    '#default_value' => variable_get('swfaddress_send_aliases', TRUE)
  );

  $form['swf_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('SWF File Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE
  );

  $form['swf_options']['heading'] = array(
    '#default_value' => t('Enter the information about your SWF file.'),
  );
  
  $form['swf_options']['swfaddress_swf_address'] = array(
    '#type' => 'textfield',
    '#title' => t('SWF URL'),
    '#description' => t('Enter the path to the SWF you want loaded relative to the site root.'),
    '#default_value' => variable_get('swfaddress_swf_address', ''),
    '#required' => TRUE
  );

  $form['swf_options']['swfaddress_flash_version'] = array(
    '#type' => 'textfield',
    '#title' => t('Minimum Flash Version'),
    '#size' => 10,
    '#maxlength' => 10,
    '#description' => t('What version of Flash must users have for the SWF replacement to take place?'),
    '#default_value' => variable_get('swfaddress_flash_version', '9.0.0'),
    '#required' => TRUE    
  );

  $form['swf_options']['swfaddress_flash_width'] = array(
    '#type' => 'textfield',
    '#title' => t('SWF Width'),
    '#size' => 6,
    '#maxlength' => 6,
    '#description' => t('The width of the SWF in pixels or as a percentage.'),
    '#default_value' => variable_get('swfaddress_flash_width', 550),
    '#required' => TRUE    
  );

  $form['swf_options']['swfaddress_flash_height'] = array(
    '#type' => 'textfield',
    '#title' => t('SWF Height'),
    '#size' => 6,
    '#maxlength' => 6,
    '#description' => t('The height of the SWF in pixels or as a percentage.'),
    '#default_value' => variable_get('swfaddress_flash_height', 400),
  '#required' => TRUE    
  );

  $form['swf_options']['swfaddress_flash_tag_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Flash Tag ID'),
    '#size' => 40,
    '#maxlength' => 40,
    '#description' => t('The HTML ID of the OBJECT and EMBED tags that SWFObject will add.  To prevent problems in Internet Explorer, this must be made up of only letters and numbers.  Minus signs will cause errors in Internet Explorer.'),
    '#default_value' => variable_get('swfaddress_flash_tag_id', 'swfembed'),
    '#required' => TRUE
  );

  $form['swf_options']['swfaddress_flash_replace_id'] = array(
    '#type' => 'textfield',
    '#title' => t('HTML ID to Replace'),
    '#size' => 40,
    '#maxlength' => 40,
    '#description' => t('The HTML ID of the tag that SWFObject will replace.'),
    '#default_value' => variable_get('swfaddress_flash_replace_id', 'swf-replace'),
    '#required' => TRUE
  );

  $form['swf_options']['swfaddress_flash_background'] = array(
    '#type' => 'textfield',
    '#title' => t('Background Color'),
    '#size' => 6,
    '#maxlength' => 6,
    '#description' => t('The six-character hexidecimal background color for the SWF.'),
    '#default_value' => variable_get('swfaddress_flash_background', 'FFFFFF'),
    '#required' => TRUE
  );

  $form['path_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Included or Excluded Paths'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE
  );

  $form['path_options']['swfaddress_base_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Base Path'),
    '#default_value' => variable_get('swfaddress_base_path', ''),
    '#maxlength' => 64,
    '#size' => 40,
    '#description' => t('Specify the path where SWFAddress should redirect the viewer if they are capable of viewing your Flash file.'),
    '#field_prefix' => url("", array('absolute' => TRUE)) . (variable_get('clean_url', 0) ? '' : '?q=')
  );

  $form['path_options']['swfaddress_include_paths'] = array(
    '#type' => 'radios',
    '#title' => t('Mode'),
    '#default_value' => variable_get('swfaddress_include_paths', 0),
    '#options' => array(
      0 => t('Exclude (Redirect on every page except the listed pages.)'),
      1 => t('Include (Redirect on only the listed pages.)'))
  );
  
  $form['path_options']['swfaddress_excluded_paths'] = array(
    '#type' => 'textarea',
    '#title' => t('Included / Excluded Paths'),
    '#rows' => 8,
    '#description' => t('Specify the paths that will be included or excluded, based on the <strong>Mode</strong> setting above. Separate paths with a return. If you are using the Exclude mode, it is advisable to exclude your administration pages with a rule such as <strong>admin*</strong>.'),
    '#default_value' => variable_get('swfaddress_excluded_paths', swfaddress_help('admin/settings/swfaddress#pages')),
    '#required' => TRUE
  );
  
  return system_settings_form($form);  
}

/**
 * Validation for swfaddress administrative settings.
 */
function swfaddress_admin_form_validate($form, &$form_state) {
  if (preg_match('/^([0-9]{1,5}[%]?)$/', $form_state['swfaddress_flash_width'])) {
    form_set_error('swfaddress_flash_width', t('Please enter a numeric or percentile width.'));
  }

  if (preg_match('/^([0-9]{1,5}[%]?)$/', $form_state['swfaddress_flash_height'])) {
    form_set_error('swfaddress_flash_height', t('Please enter a numeric or percentile height.'));
  }
  
  if (preg_match('/^([a-fA-F0-9]){6}$/', $form_state['swfaddress_flash_background'])) {
    form_set_error('swfaddress_flash_background', t('Please enter a six-character HTML color.'));
  }

  if (preg_match('/[^a-zA-Z0-9]+/', $form_state['swfaddress_flash_tag_id']) !== 0) {
    form_set_error('swfaddress_flash_tag_id', t('The HTML ID must contain only alphanumeric characters.'));
  }
}
